##  Before You Start
Before starting to evaluate your application data, ensure to have the following in place:
  * Baseline information for applications is provided, see [Application Portfolio Assessment Use Case](https://help.sap.com/docs/leanix/ea/application-portfolio-assessment?locale=en-US "https://help.sap.com/docs/leanix/ea/application-portfolio-assessment?locale=en-US")
  * Applications are scoped, see [Scope Applications](https://help.sap.com/docs/leanix/ea/application-rationalization-scope-applications?locale=en-US "https://help.sap.com/docs/leanix/ea/application-rationalization-scope-applications?locale=en-US")
  * Application data is available, see [Enrich Data](https://help.sap.com/docs/leanix/ea/application-rationalization-enrich-data?locale=en-US "https://help.sap.com/docs/leanix/ea/application-rationalization-enrich-data?locale=en-US")
    * Applications are rated for functional and technical fit
    * Application cost: Total cost of ownership (TCO) of applications including license, maintenance and support costs
    * Infrastructure cost: Total annual cost on the relation between an application and IT components
